pub(crate) struct UnrootedDom<'a, T>where
T: DomObject,{
inner: Dom<T>,
_phantom: PhantomData<&'a ()>,
}Expand description
Fields
inner: Dom<T>_phantom: PhantomData<&'a ()>Implementations
Sourceimpl<'a, T> UnrootedDom<'a, T>where
T: DomObject,
impl<'a, T> UnrootedDom<'a, T>where
T: DomObject,
Sourcepub fn from_dom(object: Dom<T>, _no_gc: &'a NoGC) -> UnrootedDom<'a, T>
pub fn from_dom(object: Dom<T>, _no_gc: &'a NoGC) -> UnrootedDom<'a, T>
Construct an UnrootedDom with the lifetime of the given NoGC token. It is
safe to keep the returned value on the stack as it cannot outlive the lifetime of
the token and the token should ensure that no garbage collection will take place
as long as it is alive.
Sourceimpl<'a, T> UnrootedDom<'a, T>where
T: Castable,
impl<'a, T> UnrootedDom<'a, T>where
T: Castable,
Sourcepub fn upcast<U>(dom: UnrootedDom<'a, T>) -> UnrootedDom<'a, U>where
U: Castable,
T: DerivedFrom<U>,
pub fn upcast<U>(dom: UnrootedDom<'a, T>) -> UnrootedDom<'a, U>where
U: Castable,
T: DerivedFrom<U>,
Cast a DOM object root upwards to one of the interfaces it derives from.
Sourcepub fn downcast<U>(dom: UnrootedDom<'a, T>) -> Option<UnrootedDom<'a, U>>where
U: DerivedFrom<T>,
pub fn downcast<U>(dom: UnrootedDom<'a, T>) -> Option<UnrootedDom<'a, U>>where
U: DerivedFrom<T>,
Cast a DOM object root downwards to one of the interfaces it might implement.