pub(crate) struct MutDom<T>where
T: DomObject,{
val: UnsafeCell<Dom<T>>,
}Expand description
A holder that provides interior mutability for GC-managed values such as
Dom<T>. Essentially a Cell<Dom<T>>, but safer.
This should only be used as a field in other DOM objects; see warning
on Dom<T>.
Fields
val: UnsafeCell<Dom<T>>Implementations
Sourceimpl<T> MutDom<T>where
T: DomObject,
impl<T> MutDom<T>where
T: DomObject,
Sourcepub fn get_unrooted<'a>(&self, _: &'a NoGC) -> UnrootedDom<'a, T>
pub fn get_unrooted<'a>(&self, _: &'a NoGC) -> UnrootedDom<'a, T>
Get the DomObject without rooting it as an UnrootedDom. This is safe as
the return value shares the lifetime of the provided NoGC This implies that
while the UnrootedDom is alive, garbage collection will not happen.