pub(crate) struct UnrootedDom<'a, T: DomObject> {
inner: Dom<T>,
_no_gc: &'a NoGC,
}Expand description
A struct to make Unrooted Dom objects work. By taking a no_gc as reference, we ensure that the lifetime of this object is bounded by the lifetime of NoGC which enforces no gc happening.
Fields
inner: Dom<T>_no_gc: &'a NoGCImplementations
Sourceimpl<'a, T: DomObject> UnrootedDom<'a, T>
impl<'a, T: DomObject> UnrootedDom<'a, T>
Sourcepub(crate) fn from_dom(object: Dom<T>, no_gc: &'a NoGC) -> UnrootedDom<'a, T>
pub(crate) fn from_dom(object: Dom<T>, no_gc: &'a NoGC) -> UnrootedDom<'a, T>
Construct an UnrootedDom with the lifetime of NoGC. This is safe, as NoGC implies no garbage collection will happen